AuditCacheKeyPayload

Struct AuditCacheKeyPayload 

pub struct AuditCacheKeyPayload {
Show 22 fields pub cache_version: u8, pub cli_version: String, pub base_sha: String, pub config_file: AuditConfigFingerprint, pub changed_files: Vec<String>, pub materialized_context: AuditMaterializedContextFingerprint, pub production: bool, pub production_dead_code: Option<bool>, pub production_health: Option<bool>, pub production_dupes: Option<bool>, pub workspace: Option<Vec<String>>, pub changed_workspaces: Option<String>, pub group_by: Option<String>, pub include_entry_exports: bool, pub max_crap: Option<f64>, pub coverage: Option<AuditCoverageFingerprint>, pub coverage_root: Option<String>, pub css: bool, pub css_deep: bool, pub dead_code_baseline: Option<String>, pub health_baseline: Option<String>, pub dupes_baseline: Option<String>,
}
Typed payload hashed to address an audit base-snapshot cache entry.

Fields

cache_version: u8

Audit base snapshot cache schema version.

cli_version: String

Fallow CLI version that produced the key.

base_sha: String

Resolved git SHA for the base ref.

config_file: AuditConfigFingerprint

Config fingerprint.

changed_files: Vec<String>

Changed files normalized to git-root-relative, forward-slash paths.

materialized_context: AuditMaterializedContextFingerprint

Host dependency and generated context materialized into the base view.

production: bool

Global production mode.

production_dead_code: Option<bool>

Dead-code-specific production override.

production_health: Option<bool>

Health-specific production override.

production_dupes: Option<bool>

Duplication-specific production override.

workspace: Option<Vec<String>>

Workspace filters.

changed_workspaces: Option<String>

Changed-workspaces base ref, when enabled.

group_by: Option<String>

Grouping mode.

include_entry_exports: bool

Whether entry exports are analyzed.

max_crap: Option<f64>

CRAP threshold override.

coverage: Option<AuditCoverageFingerprint>

Coverage input fingerprint.

coverage_root: Option<String>

Coverage root override.

css: bool

Whether audit health computed styling keys for the base snapshot.

css_deep: bool

Whether audit health used deep CSS analysis for the base snapshot.

dead_code_baseline: Option<String>

Dead-code baseline path.

health_baseline: Option<String>

Health baseline path.

dupes_baseline: Option<String>

Duplication baseline path.