pub struct AuditConfigFingerprint {
pub path: Option<String>,
pub resolved_hash: Option<String>,
}Expand description
Fingerprint of the resolved config that can affect audit output.
Fields
path: Option<String>Path of the config file that was loaded, or None when no config exists.
resolved_hash: Option<String>Stable hash of the resolved config object.