pub struct AuditCoverageFingerprint {
pub path: String,
pub resolved_path: String,
pub source: Option<SourceFingerprint>,
pub content_hash: Option<String>,
pub len: Option<usize>,
pub error: Option<String>,
}Expand description
Fingerprint of an optional coverage input that can affect health findings.
Fields
path: StringUser-provided coverage path.
resolved_path: StringActual file path hashed after directory resolution.
source: Option<SourceFingerprint>Metadata freshness for the resolved coverage file, when it was readable.
content_hash: Option<String>Stable content hash for the resolved coverage file, when it was readable.
len: Option<usize>File length in bytes, when it was readable.
error: Option<String>I/O error kind, when the resolved coverage file was not readable.