pub fn command_envelope(command: &str) -> Option<&'static CommandEnvelope>Expand description
The row of command, when it is an analysis subcommand.
pub fn command_envelope(command: &str) -> Option<&'static CommandEnvelope>The row of command, when it is an analysis subcommand.