#[non_exhaustive]pub enum CloneGroupKind {
Exact,
Near {
similarity: f64,
},
}Expand description
Whether a clone group is exact or a near-miss match.
This is derived from the serialized clone-group fields and does not add a separate discriminator to the output contract.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exact
An exact or normalization-equivalent clone group.
Near
A near-miss group and its lowest all-pairs similarity.