clone_location_spread

Function clone_location_spread 

pub fn clone_location_spread<'a>(
    locations: impl IntoIterator<Item = (&'a Path, usize, usize)>,
) -> usize
Compute clone spread from borrowed file and line locations.

This is equivalent to clone_group_spread without requiring callers that wrap clone instances to clone their source fragments.