Module extract

Module extract 

Module extraction types: exports, imports, re-exports, and member info. Module extraction types: exports, imports, re-exports, members, and parse results.

Structs

DynamicImportInfo
A dynamic import() call.
DynamicImportPattern
A dynamic import with a pattern that can be partially resolved (e.g., template literals).
ExportInfo
An export declaration.
ImportInfo
An import declaration.
MemberAccess
A static member access expression (e.g., Status.Active, MyClass.create()).
MemberInfo
A member of an enum or class.
ModuleInfo
Extracted module information from a single file.
ParseResult
Result of parsing all files, including incremental cache statistics.
ReExportInfo
A re-export declaration.
RequireCallInfo
A require() call.

Enums

ExportName
Export identifier.
ImportedName
How a symbol is imported.
MemberKind
The kind of member.

Functions

byte_offset_to_line_col
Convert a byte offset to a 1-based line number and 0-based byte column using a pre-computed line offset table (from compute_line_offsets).
compute_line_offsets
Compute a table of line-start byte offsets from source text.