pub enum ImportBindingReferenceKind {
InitializerCall,
ValueAlias,
JsxElement,
Other,
Call,
}Expand description
How the code uses an ImportBindingReference.
Variants
InitializerCall
An admitted call that is the whole initializer of a top-level
declarator: const x = useSelector.withTypes<T>().
ValueAlias
The reference is the whole initializer of a declarator:
const x = useDispatch.
JsxElement
The reference names a JSX opening element: <Provider>.
Other
Any other value use that is not an admitted call, for example an argument, an array element or an optional call.
Call
A direct call of a wrapper declarator in its own module. Only a
reference with through set has this kind.