pub struct FlagRegistryFacts {
pub registries: Vec<FlagKeyRegistry>,
pub reads: Vec<FlagRegistryRead>,
pub constants: Vec<FlagConstant>,
pub definitions: Vec<FlagDefinition>,
}Expand description
Registry facts, and other flag facts outside the per-site findings, that a module gives to feature flag analysis.
Fields
registries: Vec<FlagKeyRegistry>Registries this module exports.
reads: Vec<FlagRegistryRead>Flag reads that name a member of an imported registry.
constants: Vec<FlagConstant>Literal const flags that a guard in the module tests.
definitions: Vec<FlagDefinition>Flag definitions bound to a const.
Implementations