pub struct ImportLoadKindOverrideFact {
pub span_start: u32,
pub kind: ImportLoadKind,
}Expand description
The load kind of the dynamic imports or patterns that start at span_start.
Fields
span_start: u32Byte offset of the call or new expression that records the edge.
kind: ImportLoadKindThe load kind of every edge that the expression records.