Guard output contracts for pre-edit architecture-rule lookup. Guard report contracts for pre-edit architecture guidance.
Structs
- Guard
Boundary - Boundary permissions and call restrictions for a guard target.
- Guard
File Report - Guard information for a single project-root-relative path.
- Guard
Policy Rule - Rule-pack policy rule that applies to a guard target.
- Guard
Report - Per-file guard report for one or more requested paths.
- Guard
Severities - Effective guard-relevant rule severities for a target path.
- Guard
Zone - Boundary zone matched by a guard target.