pub struct GuardReport {
pub files: Vec<GuardFileReport>,
}Expand description
Per-file guard report for one or more requested paths.
Fields
files: Vec<GuardFileReport>Reports in the same order as the requested files.