pub struct SuppressFileAction {
pub kind: SuppressFileKind,
pub auto_fixable: bool,
pub description: String,
pub comment: String,
}Expand description
File-wide suppression placed at the top of the source file.
Fields
kind: SuppressFileKindAction type identifier.
auto_fixable: boolAlways false for suppress actions.
description: StringHuman-readable description of the suppression.
comment: StringThe file-level comment to place at the top of the file (e.g.,
// fallow-ignore-file unused-file).