pub struct TypeOnlyDependency {
pub package_name: String,
pub path: PathBuf,
pub line: u32,
}Expand description
A production dependency that is only used via type-only imports. In production builds, type imports are erased, so this dependency is not needed at runtime and could be moved to devDependencies.
Fields
package_name: StringProduction dependency that is only used via type-only imports.
path: PathBufPath to the package.json where the dependency is listed.
line: u321-based line number of the dependency entry in package.json.