pub struct UnresolvedImport {
pub path: PathBuf,
pub specifier: String,
pub line: u32,
pub col: u32,
pub specifier_col: u32,
}Expand description
An import that could not be resolved.
Fields
path: PathBufFile containing the unresolved import.
specifier: StringThe import specifier that could not be resolved.
line: u321-based line number.
col: u320-based byte column offset of the import statement.
specifier_col: u320-based byte column offset of the source string literal (the specifier in quotes). Used by the LSP to underline just the specifier, not the entire import line.