FileTrace

Struct FileTrace 

pub struct FileTrace {
    pub file: PathBuf,
    pub is_reachable: bool,
    pub is_entry_point: bool,
    pub exports: Vec<TracedExport>,
    pub imports_from: Vec<PathBuf>,
    pub imported_by: Vec<PathBuf>,
    pub re_exports: Vec<TracedReExport>,
    pub sources: Vec<TraceSource>,
}
Result of tracing all edges for a file.

Fields

file: PathBuf

The traced file.

is_reachable: bool

Whether this file is reachable from entry points.

is_entry_point: bool

Whether this file is an entry point.

exports: Vec<TracedExport>

Exports declared by this file.

imports_from: Vec<PathBuf>

Files that this file imports from.

imported_by: Vec<PathBuf>

Files that import from this file.

re_exports: Vec<TracedReExport>

Re-exports declared by this file.

sources: Vec<TraceSource>

The configs that make this file an entry point through Module Federation exposes, one per config. Absent when no Federation config exposes the file (issue #2796).