pub struct UsageWrapper {
pub file: String,
pub export: String,
pub shape: WrapperShape,
pub line: u32,
pub consumer_file_count: usize,
pub call_site_count: usize,
}Expand description
A top-level exported declarator that wraps an imported name. The trace follows one hop from the wrapper to its consumers.
Fields
file: StringThe file that declares the wrapper, root-relative.
export: StringThe exported name of the wrapper.
shape: WrapperShapeThe shape of the wrapper.
line: u321-based line of the wrapper initializer.
consumer_file_count: usizeDistinct files with a call of the wrapper, the file of the wrapper included.
call_site_count: usizeCalls of the wrapper itself. A call of a member of the value that a
call wrapper returns (store.dispatch()) is a non_call_reference.