Typed audit cache-key inputs. Typed audit cache-key inputs.
Structs
- Audit
Cache KeyBuilder - Builder for audit base-snapshot cache keys.
- Audit
Cache KeyPayload - Typed payload hashed to address an audit base-snapshot cache entry.
- Audit
Config Fingerprint - Fingerprint of the resolved config that can affect audit output.
- Audit
Context Directory Fingerprint - Fingerprint of one host directory materialized into an audit base worktree.
- Audit
Context File Fingerprint - Fingerprint of one file that can affect base-worktree resolution.
- Audit
Coverage Fingerprint - Fingerprint of an optional coverage input that can affect health findings.
- Audit
Materialized Context Fingerprint - Bounded host context shared with an audit base worktree.
Enums
- Audit
Context Path State - Filesystem state of one bounded audit context input.