Module audit_cache

Module audit_cache 

Typed audit cache-key inputs. Typed audit cache-key inputs.

Structs

AuditCacheKeyBuilder
Builder for audit base-snapshot cache keys.
AuditCacheKeyPayload
Typed payload hashed to address an audit base-snapshot cache entry.
AuditConfigFingerprint
Fingerprint of the resolved config that can affect audit output.
AuditCoverageFingerprint
Fingerprint of an optional coverage input that can affect health findings.