Module duplicates

Module duplicates 

Shared duplicate-code output contracts. Shared duplicate-code output contracts.

Structs

CloneFamily
A clone family: a set of clone groups that share the same file set.
CloneGroup
A group of code clones – the same (or normalized-equivalent) code appearing in multiple places.
CloneInstance
A single instance of duplicated code at a specific location.
DefaultIgnoreSkipCount
Number of files skipped by one built-in duplicates ignore pattern.
DefaultIgnoreSkips
Human-format-only skipped-file stats for built-in duplicates ignores.
DuplicationReport
Overall duplication analysis report.
DuplicationStats
Aggregate duplication statistics.
MirroredDirectory
A detected mirrored directory pattern: two directory prefixes that contain identical files (e.g., src/ and deno/lib/).
RefactoringSuggestion
A refactoring suggestion for a clone family.

Enums

CloneGroupKind
Whether a clone group is exact or a near-miss match.
RefactoringKind
The kind of refactoring suggested for a clone family.

Functions

clone_group_spread
Compute the maximum distance between clone instances.
clone_location_spread
Compute clone spread from borrowed file and line locations.
compare_clone_groups
Compare clone groups in shared spread-aware priority order.