Shared duplicate-code output contracts. Shared duplicate-code output contracts.
Structs
- Clone
Family - A clone family: a set of clone groups that share the same file set.
- Clone
Group - A group of code clones – the same (or normalized-equivalent) code appearing in multiple places.
- Clone
Instance - A single instance of duplicated code at a specific location.
- Default
Ignore Skip Count - Number of files skipped by one built-in duplicates ignore pattern.
- Default
Ignore Skips - Human-format-only skipped-file stats for built-in duplicates ignores.
- Duplication
Report - Overall duplication analysis report.
- Duplication
Stats - Aggregate duplication statistics.
- Mirrored
Directory - A detected mirrored directory pattern: two directory prefixes that contain
identical files (e.g.,
src/anddeno/lib/). - Refactoring
Suggestion - A refactoring suggestion for a clone family.
Enums
- Refactoring
Kind - The kind of refactoring suggested for a clone family.