pub enum TypeAwareProjectStatus {
Refined,
Abstained,
Complete,
Unavailable,
}Expand description
Outcome of semantic refinement for one TypeScript project.
Variants
Refined
The project was structurally safe and its candidates were scanned.
Abstained
Structural diagnostics prevented candidate scanning.
Complete
All semantic queries assigned to this Program completed.
The Program could not answer its assigned semantic queries safely.