Module extraction types: exports, imports, re-exports, and member info. Module extraction types: exports, imports, re-exports, members, and parse results.
Structs
- Dynamic
Import Info - A dynamic
import()call. - Dynamic
Import Pattern - A dynamic import with a pattern that can be partially resolved (e.g., template literals).
- Export
Info - An export declaration.
- Import
Info - An import declaration.
- Member
Access - A static member access expression (e.g.,
Status.Active,MyClass.create()). - Member
Info - A member of an enum or class.
- Module
Info - Extracted module information from a single file.
- Parse
Result - Result of parsing all files, including incremental cache statistics.
- ReExport
Info - A re-export declaration.
- Require
Call Info - A
require()call.
Enums
- Export
Name - Export identifier.
- Imported
Name - How a symbol is imported.
- Member
Kind - The kind of member.
Functions
- byte_
offset_ to_ line_ col - Convert a byte offset to a 1-based line number and 0-based byte column
using a pre-computed line offset table (from
compute_line_offsets). - compute_
line_ offsets - Compute a table of line-start byte offsets from source text.