pub enum SecurityUrlShape {
FixedOriginDynamicPath,
DynamicOrigin,
}Expand description
Static URL construction shape captured for URL-shaped security sinks.
Variants
FixedOriginDynamicPath
The sink target has a fixed origin, scheme, or relative root while only path or query components are dynamic.
DynamicOrigin
The sink target’s scheme or origin is dynamic or opaque.