Module guard

Module guard 

Guard output contracts for pre-edit architecture-rule lookup. Guard report contracts for pre-edit architecture guidance.

Structs

GuardBoundary
Boundary permissions and call restrictions for a guard target.
GuardFileReport
Guard information for a single project-root-relative path.
GuardPolicyRule
Rule-pack policy rule that applies to a guard target.
GuardReport
Per-file guard report for one or more requested paths.
GuardSeverities
Effective guard-relevant rule severities for a target path.
GuardZone
Boundary zone matched by a guard target.