pub struct StaleSuppression {
pub path: PathBuf,
pub line: u32,
pub col: u32,
pub origin: SuppressionOrigin,
}Expand description
A suppression comment or JSDoc tag that no longer matches any issue.
Fields
path: PathBufFile containing the stale suppression.
line: u321-based line number of the suppression comment or tag.
col: u320-based byte column offset.
origin: SuppressionOriginThe origin and details of the stale suppression.
Implementations
Sourceimpl StaleSuppression
impl StaleSuppression
Sourcepub fn description(&self) -> String
pub fn description(&self) -> String
Produce a human-readable description of this stale suppression.
Sourcepub fn explanation(&self) -> String
pub fn explanation(&self) -> String
Produce an explanation of why this suppression is stale.
Sourcepub fn suppressed_kind(&self) -> Option<IssueKind>
pub fn suppressed_kind(&self) -> Option<IssueKind>
The suppressed IssueKind, if this was a comment suppression with a specific kind.