Trace output contracts shared by core, engine, CLI, API, and MCP. Shared trace output contracts for analysis and integration surfaces.
Structs
- Clone
Trace - Result of tracing a clone: all groups containing the code at a source location or addressed by a stable clone fingerprint.
- Dependency
Trace - Result of tracing a dependency: where it is used.
- Export
Reference - A direct reference to an export.
- Export
Trace - Result of tracing an export: why it is considered used or unused.
- File
Trace - Result of tracing all edges for a file.
- Impact
Closure Gap - One coordination-gap entry in an
ImpactClosureTrace. - Impact
Closure Trace - Result of computing the impact closure for a single file as the seed.
- Pipeline
Timings - Pipeline performance timings.
- ReExport
Chain - A re-export chain showing how an export is propagated.
- Traced
Clone Group - One clone group returned from a clone trace request.
- Traced
Export - An export with usage information.
- Traced
ReExport - A re-export with source information.